@@ -1,6 +1,6 @@
 ##########################################################################################
 # Designed and developed by Tinniam V Ganesh
-# Date : 2 May 2020
+# Date : 24 Apr 2021
 # Function: plotWinLossBetweenTeams
 # This function computes and plots number of wins for each team
 #
@@ -56,29 +56,13 @@ plotWinLossBetweenTeams <- function(team1,team2,dir="."){
     matches=NULL
     venue=winner=result=date=NULL
     # Create 2 filenames with both combinations of team1 and team2
-    d1 <- paste(team1,"-",team2,"*",sep="")
-    d2 <- paste(team2,"-",team1,"*",sep="")
-    path1=paste(dir,"/",d1,sep="")
-    path2=paste(dir,"/",d2,sep="")
-    # Capture both combinations
-    fl1 <- Sys.glob(path1)
-    fl2 <- Sys.glob(path2)
-    fl3 <-c(fl1,fl2)
+    d1 <-paste(team1,"-",team2,"-allMatches.RData",sep="")
+    fl1 <- paste(dir,"/",d1,sep="")
+    load(fl1)
+    a <- select(matches,date,venue,winner,result)
+    b=distinct(a) #Get distinct rows
 
-    # Create a data frame with all matches
-    matches <- NULL
-    w <- NULL
-    for(i in 1:length(fl3)){
-        load(fl3[i])
-        # Find rows by winnner, venue, date and result
-        a <- select(matches,date,venue,winner,result)
-        b=distinct(a) #Get distinct rows
-        w <- rbind(w,b)
-        matches <- NULL
-    }
-    # Get all unique rows between 2 teams
-    v <- distinct(w)
-    winLoss <- summarise(group_by(v,winner),count=n())
+    winLoss <- summarise(group_by(b,winner),count=n())
 
     x <- winLoss$winner=="NA"
     winLoss$winner <- as.character(winLoss$winner)
